---
title: I18n
excerpt: Internationalization/localization features in Workarea allow for translation/customization of static content (including message content and JavaScript content) and translation of administrable content.
---

# I18n

Internationalization/localization features in Workarea allow for [translation/customization of static content](translate-or-customize-static-content.html) (including [message content](translate-or-customize-message-content.html) and [JavaScript content](translate-javascript-content.html)) and [translation of administrable content](translate-administrable-content.html).

**Note:** Internationalization/localization in Workarea relies heavily on [Rails I18n](http://guides.rubyonrails.org/i18n.html) and [Mongoid Localization](https://docs.mongodb.org/ecosystem/tutorial/ruby-mongoid-tutorial/#localized-fields). The preceding links provide excellent explanations of those features, so they are recommended reading.

## Customizing Text

Rails I18n features are useful even if your app has only a single locale. Use I18n to customize static text strings, such as [the content of success, failure, and warning messages](translate-or-customize-message-content.html).

## Translating Text

Of course, your app may also use multiple locales to provide [static content translations](translate-or-customize-static-content.html) and [translation of administrable content](translate-administrable-content.html).

To use multiple locales, start by [configuring locales](configure-locales.html).

## Determining the Current Locale

Workarea determines the current locale by looking for a locale prefix in the request URL.

Given an app with en (default), es, and de locales, the following table demonstrates how each URL maps to a locale.

| URL | Locale |
| --- | --- |
| http://example.com/categories/sale | en (default) |
| http://example.com/en/categories/sale | en |
| http://example.com/es/categories/sale | es |
| http://example.com/de/categories/sale | de |


